# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-07-08 10:14:46
@LastEditTime: 2020-10-12 09:44:42
@LastEditors: HuangJingCan
@Description: 
"""
from seven_top.top.api.rest.MiniappCloudMongoInsertRequest import MiniappCloudMongoInsertRequest
from seven_top.top.api.rest.MiniappCloudMongoUpdateRequest import MiniappCloudMongoUpdateRequest
from seven_top.top.api.rest.AlibabaBenefitDrawRequest import AlibabaBenefitDrawRequest
from seven_top.top.api.rest.AlibabaBenefitQueryRequest import AlibabaBenefitQueryRequest
from seven_top.top.api.rest.AlibabaBenefitSendRequest import AlibabaBenefitSendRequest
from seven_top.top.api.rest.AlibabaBeneiftDrawRequest import AlibabaBeneiftDrawRequest

from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyttsRequest import AlibabaAliqinTaNumberSinglecallbyttsRequest
from seven_top.top.api.rest.SkusCustomGetRequest import SkusCustomGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountReportRequest import JstSmsOfficialaccountReportRequest
from seven_top.top.api.rest.TmcMessageProduceRequest import TmcMessageProduceRequest
from seven_top.top.api.rest.ItemsCustomGetRequest import ItemsCustomGetRequest
from seven_top.top.api.rest.FuwuSaleLinkGenRequest import FuwuSaleLinkGenRequest
from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyvoiceRequest import AlibabaAliqinTaNumberSinglecallbyvoiceRequest
from seven_top.top.api.rest.ItemSellerGetRequest import ItemSellerGetRequest
from seven_top.top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from seven_top.top.api.rest.TmcMessagesProduceRequest import TmcMessagesProduceRequest
from seven_top.top.api.rest.SubuserDepartmentsGetRequest import SubuserDepartmentsGetRequest
from seven_top.top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateRequest import MiniappTemplateUpdateRequest
from seven_top.top.api.rest.ItemsOnsaleGetRequest import ItemsOnsaleGetRequest
from seven_top.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from seven_top.top.api.rest.SellercenterSubusersGetRequest import SellercenterSubusersGetRequest
from seven_top.top.api.rest.SellercenterRolemembersGetRequest import SellercenterRolemembersGetRequest
from seven_top.top.api.rest.MiniappTemplateQueryappRequest import MiniappTemplateQueryappRequest
from seven_top.top.api.rest.FuwuScoresGetRequest import FuwuScoresGetRequest
from seven_top.top.api.rest.ItempropvaluesGetRequest import ItempropvaluesGetRequest
from seven_top.top.api.rest.MiniappTemplateOnlineappRequest import MiniappTemplateOnlineappRequest
from seven_top.top.api.rest.FilesGetRequest import FilesGetRequest
from seven_top.top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from seven_top.top.api.rest.TmcMessagesConsumeRequest import TmcMessagesConsumeRequest
from seven_top.top.api.rest.SellercenterRolesGetRequest import SellercenterRolesGetRequest
from seven_top.top.api.rest.VasSubscSearchRequest import VasSubscSearchRequest
from seven_top.top.api.rest.ItemcatsGetRequest import ItemcatsGetRequest
from seven_top.top.api.rest.SellercatsListGetRequest import SellercatsListGetRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumSendRequest import AlibabaAliqinTaSmsNumSendRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOnlineRequest import JstSmsOfficialaccountOnlineRequest
from seven_top.top.api.rest.JstSmsOfficialaccountCancelRequest import JstSmsOfficialaccountCancelRequest
from seven_top.top.api.rest.SellercenterRoleInfoGetRequest import SellercenterRoleInfoGetRequest
from seven_top.top.api.rest.JstSmsMessageSendRequest import JstSmsMessageSendRequest
from seven_top.top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from seven_top.top.api.rest.TmcGroupDeleteRequest import TmcGroupDeleteRequest
from seven_top.top.api.rest.ShopSellerGetRequest import ShopSellerGetRequest
from seven_top.top.api.rest.SellercenterUserPermissionsGetRequest import SellercenterUserPermissionsGetRequest
from seven_top.top.api.rest.CrmMemberIdentityGetRequest import CrmMemberIdentityGetRequest
from seven_top.top.api.rest.TmcTopicGroupAddRequest import TmcTopicGroupAddRequest
from seven_top.top.api.rest.ShopcatsListGetRequest import ShopcatsListGetRequest
from seven_top.top.api.rest.TmcGroupsGetRequest import TmcGroupsGetRequest
from seven_top.top.api.rest.CrmMemberJoinurlGetRequest import CrmMemberJoinurlGetRequest
from seven_top.top.api.rest.VasOrderSearchRequest import VasOrderSearchRequest
from seven_top.top.api.rest.JstSmsStatusQueryRequest import JstSmsStatusQueryRequest
from seven_top.top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from seven_top.top.api.rest.TmcTopicGroupDeleteRequest import TmcTopicGroupDeleteRequest
from seven_top.top.api.rest.AppipGetRequest import AppipGetRequest
from seven_top.top.api.rest.OpenTradeGetRequest import OpenTradeGetRequest
from seven_top.top.api.rest.TimeGetRequest import TimeGetRequest
from seven_top.top.api.rest.TmcMessagesConfirmRequest import TmcMessagesConfirmRequest
from seven_top.top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateappRequest import MiniappTemplateUpdateappRequest
from seven_top.top.api.rest.ItemsSellerListGetRequest import ItemsSellerListGetRequest
from seven_top.top.api.rest.SellercenterRoleAddRequest import SellercenterRoleAddRequest
from seven_top.top.api.rest.TmcUserPermitRequest import TmcUserPermitRequest
from seven_top.top.api.rest.ItempropsGetRequest import ItempropsGetRequest
from seven_top.top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOfflineRequest import JstSmsOfficialaccountOfflineRequest
from seven_top.top.api.rest.MiniappUserInfoGetRequest import MiniappUserInfoGetRequest
from seven_top.top.api.rest.ItemcatsAuthorizeGetRequest import ItemcatsAuthorizeGetRequest
from seven_top.top.api.rest.UserSellerGetRequest import UserSellerGetRequest
from seven_top.top.api.rest.ItemsInventoryGetRequest import ItemsInventoryGetRequest
from seven_top.top.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from seven_top.top.api.rest.ItemSkusGetRequest import ItemSkusGetRequest
from seven_top.top.api.rest.SubuserDutysGetRequest import SubuserDutysGetRequest
from seven_top.top.api.rest.SubuserInfoUpdateRequest import SubuserInfoUpdateRequest
from seven_top.top.api.rest.TmcUserCancelRequest import TmcUserCancelRequest
from seven_top.top.api.rest.MiniappItemsGetRequest import MiniappItemsGetRequest
from seven_top.top.api.rest.AlibabaAliqinTaVoiceNumDoublecallRequest import AlibabaAliqinTaVoiceNumDoublecallRequest
from seven_top.top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from seven_top.top.api.rest.SubuserFullinfoGetRequest import SubuserFullinfoGetRequest
from seven_top.top.api.rest.TmcGroupAddRequest import TmcGroupAddRequest
from seven_top.top.api.rest.JstSmsMessageBatchsendRequest import JstSmsMessageBatchsendRequest
from seven_top.top.api.rest.OpenlinkSessionGetRequest import OpenlinkSessionGetRequest
from seven_top.top.api.rest.MiniapppTemplateInstantiateRequest import MiniapppTemplateInstantiateRequest
from seven_top.top.api.rest.MiniappTemplateInstantiateRequest import MiniappTemplateInstantiateRequest
from seven_top.top.api.rest.ItemSkuGetRequest import ItemSkuGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOrderRequest import JstSmsOfficialaccountOrderRequest
from seven_top.top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from seven_top.top.api.rest.JstSmsMenuinfoReportRequest import JstSmsMenuinfoReportRequest
from seven_top.top.api.rest.MiniappDistributionItemsBindRequest import MiniappDistributionItemsBindRequest
from seven_top.top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumQueryRequest import AlibabaAliqinTaSmsNumQueryRequest
from seven_top.top.api.rest.OpenTradesSoldGetRequest import OpenTradesSoldGetRequest
from seven_top.top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from seven_top.top.api.rest.SellercenterSubuserPermissionsRolesGetRequest import SellercenterSubuserPermissionsRolesGetRequest
from seven_top.top.api.rest.SubusersGetRequest import SubusersGetRequest
from seven_top.top.api.rest.TmcUserGetRequest import TmcUserGetRequest
from seven_top.top.api.rest.JstSmsExtendcodeQueryRequest import JstSmsExtendcodeQueryRequest
from seven_top.top.api.rest.SubuserEmployeeAddRequest import SubuserEmployeeAddRequest
from seven_top.top.api.rest.AppstoreSubscribeGetRequest import AppstoreSubscribeGetRequest
from seven_top.top.api.rest.TmcAuthGetRequest import TmcAuthGetRequest
